import sys
import json

from testwizard.commands_core import CommandBase
from .GetSizeResult import GetSizeResult


class GetElementSizeCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.GetElementSize")

    def execute(self, selector):
        requestObj = [selector]

        result = self.executeCommand(requestObj)

        return GetSizeResult(result, "GetElementSize was successful", "GetElementSize failed")



import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class ScreenshotResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(self, result["ok"] is True, successMessage, failMessage)

        self.filePath = result["generatedFilename"]

        if self.success is True:
            return

        self.message = self.message + result["errorMessage"]


import sys
import json

from testwizard.commands_core import CommandBase
from .GetOrientationResult import GetOrientationResult


class GetOrientationCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.GetOrientation")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj)

        return GetOrientationResult(result, "GetOrientation was successful", "GetOrientation failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetElementLocationResult import GetElementLocationResult


class GetElementLocationCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject,
                             "Mobile.GetElementLocation")

    def execute(self, selector):
        requestObj = [selector]

        result = self.executeCommand(requestObj)

        return GetElementLocationResult(result, "GetElementLocation was successful", "GetElementLocation failed")



import json
import sys

from testwizard.commands_core.ResultBase import ResultBase


class InitDriverResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(self, result["ok"] is True, successMessage, failMessage)

        self.executorUrl = result["executorUrl"]
        self.sessionId = result["sessionId"]

        if self.success is True:
            return

        self.errorCode = result["errorCode"]
        self.message = self.getMessageForErrorCode(self.message, result["errorCode"])



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class StartDeviceLoggingCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.StartDeviceLogging")

    def execute(self, filename, username, password):
        requestObj = [filename, username, password]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "StartDeviceLogging was successful", "StartDeviceLogging failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class AddCapabilityCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.AddCapability")

    def execute(self, name, value):
        requestObj = [name, value]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "AddCapability was successful", "AddCapability failed")



from .AddCapabilityCommand import AddCapabilityCommand
from .Android_SendKeyCodeCommand import Android_SendKeyCodeCommand
from .ClearElementCommand import ClearElementCommand
from .ClickElementCommand import ClickElementCommand
from .ClickPositionCommand import ClickPositionCommand
from .CloseAppCommand import CloseAppCommand
from .RemoveAppCommand import RemoveAppCommand
from .FindElementCommand import FindElementCommand
from .GetAppiumSettingsCommand import GetAppiumSettingsCommand
from .GetElementCommand import GetElementCommand
from .GetElementAttributeCommand import GetElementAttributeCommand
from .GetElementLocationCommand import GetElementLocationCommand
from .GetElementsCommand import GetElementsCommand
from .GetElementSizeCommand import GetElementSizeCommand
from .GetOrientationCommand import GetOrientationCommand
from .GetScreenSizeCommand import GetScreenSizeCommand
from .GetSourceCommand import GetSourceCommand
from .HideKeyboardCommand import HideKeyboardCommand
from .InitDriverCommand import InitDriverCommand
from .InputTextCommand import InputTextCommand
from .LaunchAppCommand import LaunchAppCommand
from .MultiTouch_AddCommand import MultiTouch_AddCommand
from .MultiTouch_NewCommand import MultiTouch_NewCommand
from .MultiTouch_PerformCommand import MultiTouch_PerformCommand
from .PinchCoordinatesCommand import PinchCoordinatesCommand
from .PinchElementCommand import PinchElementCommand
from .QuitDriverCommand import QuitDriverCommand
from .ResetAppCommand import ResetAppCommand
from .RunAppInBackgroundCommand import RunAppInBackgroundCommand
from .ScreenshotBMPCommand import ScreenshotBMPCommand
from .ScreenShotJPGCommand import ScreenShotJPGCommand
from .SetAppiumSettingsCommand import SetAppiumSettingsCommand
from .SetOrientationCommand import SetOrientationCommand
from .StartDeviceLoggingCommand import StartDeviceLoggingCommand
from .StopDeviceLoggingCommand import StopDeviceLoggingCommand
from .SwipeArcCommand import SwipeArcCommand
from .SwipeCommand import SwipeCommand
from .TouchAction_MoveToCommand import TouchAction_MoveToCommand
from .TouchAction_MoveToElementCommand import TouchAction_MoveToElementCommand
from .TouchAction_NewCommand import TouchAction_NewCommand
from .TouchAction_PerformCommand import TouchAction_PerformCommand
from .TouchAction_PressCommand import TouchAction_PressCommand
from .TouchAction_PressElementCommand import TouchAction_PressElementCommand
from .TouchAction_ReleaseCommand import TouchAction_ReleaseCommand
from .TouchAction_TapCommand import TouchAction_TapCommand
from .TouchAction_WaitCommand import TouchAction_WaitCommand
from .WaitForElementCommand import WaitForElementCommand
from .ZoomCoordinatesCommand import ZoomCoordinatesCommand
from .ZoomElementCommand import ZoomElementCommand



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class TouchAction_NewCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(
            self, testObject, "Mobile.TouchAction_NewTouchAction")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "TouchAction_New was successful", "TouchAction_New failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class SwipeArcCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.SwipeArc")

    def execute(self, centerX, centerY, radius, startDegree, degrees, steps):
        requestObj = [centerX, centerY, radius, startDegree, degrees, steps]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "SwipeArc was successful", "SwipeArc failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class ClickPositionCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.ClickPosition")

    def execute(self, x, y):
        requestObj = [x, y]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "ClickPosition was successful", "ClickPosition failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetAppiumSettingsResult import GetAppiumSettingsResult


class GetAppiumSettingsCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.GetAppiumSettings")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj)

        return GetAppiumSettingsResult(result, "GetAppiumSettings was successful", "GetAppiumSettings failed")



import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class GetSizeResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(self, result["ok"] is True, successMessage, failMessage + ": " + result["errorMessage"])

        self.width = result["width"]
        self.height = result["height"]


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase


class WaitForElementResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(
            self, result["elementFound"], successMessage, failMessage + ": " + result["errorMessage"])

        self.time = result["time"]



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class MultiTouch_PerformCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.MultiTouch_Perform")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "MultiTouch_Perform was successful", "MultiTouch_Perform failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetSourceResult import GetSourceResult

class GetSourceCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.GetSource")
    
    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj)

        return GetSourceResult(result, "GetSource was successful", "GetSource failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class Android_SendKeyCodeCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.Android_SendKeyCode")

    def execute(self, keyCode):
        requestObj = [keyCode]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "Android_SendKeyCode was successful", "Android_SendKeyCode failed")



import sys

from testwizard.commands_core import CommandBase
from .InitDriverResult import InitDriverResult
import json
class InitDriverCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.InitDriver")
    
    def execute(self, appPath):
        if appPath is None:
            requestObj = []
        else:
            requestObj = [appPath]

        result = self.executeCommand(requestObj)
        
        return InitDriverResult(result, "InitDriver was successful", "InitDriver failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from .GetElementResult import GetElementResult


class GetElementCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.GetElement")

    def execute(self, selector):
        requestObj = [selector]

        result = self.executeCommand(requestObj)

        return GetElementResult(result, "GetElement was successful", "GetElement failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class RunAppInBackgroundCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.RunAppInBackground")

    def execute(self, seconds):
        if seconds is None:
            requestObj = []
        else:
            requestObj = [seconds]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "RunAppInBackground was successful", "RunAppInBackground failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .ScreenshotResult import ScreenshotResult


class ScreenshotBMPCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.ScreenshotBMP")

    def execute(self, filename):
        requestObj = [filename]

        result = self.executeCommand(requestObj)

        return ScreenshotResult(result, "ScreenshotBMP was successful", "ScreenshotBMP failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetElementsResult import GetElementsResult


class GetElementsCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.GetElements")

    def execute(self, selector):
        requestObj = [selector]

        result = self.executeCommand(requestObj)

        return GetElementsResult(result, "GetElements was successful", "GetElements failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetElementAttributeResult import GetElementAttributeResult


class GetElementAttributeCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.GetElementAttribute")

    def execute(self, selector, attribute):
        requestObj = [selector, attribute]

        result = self.executeCommand(requestObj)

        return GetElementAttributeResult(result, "GetElementAttribute was successful", "GetElementAttribute failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class TouchAction_TapCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.TouchAction_Tap")

    def execute(self, x, y):
        requestObj = [x, y]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "TouchAction_Tap was successful", "TouchAction_Tap failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class SwipeCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.Swipe")

    def execute(self, startX, startY, endX, endY, duration):
        requestObj = [startX, startY, endX, endY, duration]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "Swipe was successful", "Swipe failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .WaitForElementResult import WaitForElementResult

class WaitForElementCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.WaitForElement")

    def execute(self, selector, maxSeconds):
        requestObj = [selector, maxSeconds]

        result = self.executeCommand(requestObj)

        return WaitForElementResult(result, "WaitForElement was successful", "WaitForElement failed")


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class SetAppiumSettingsCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.SetAppiumSettings")

    def execute(self, settings):
        requestObj = [json.dumps(settings)]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "SetAppiumSettings was successful", "SetAppiumSettings failed")



import sys
import json

from testwizard.commands_core.ResultBase import ResultBase


class GetSourceResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(
            self, result["ok"] is True, successMessage, failMessage + ": " + result["errorMessage"])

        self.source = result["source"]



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class ZoomCoordinatesCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.ZoomCoordinates")

    def execute(self, x, y, length):
        requestObj = [x, y, length]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "ZoomCoordinates was successful", "ZoomCoordinates failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .ScreenshotResult import ScreenshotResult


class ScreenShotJPGCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.ScreenshotJPG")

    def execute(self, filename, quality):
        requestObj = [filename]
        if quality is not None:
            requestObj = [filename, quality]

        result = self.executeCommand(requestObj)

        return ScreenshotResult(result, "ScreenshotJPG was successful", "ScreenshotJPG failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetSizeResult import GetSizeResult


class GetScreenSizeCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.GetScreenSize")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj)

        return GetSizeResult(result, "GetScreenSize was successful", "GetScreenSize failed")




import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class HideKeyboardCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.HideKeyboard")

    def execute(self, iOS_Key):
        if iOS_Key is None:
            requestObj = []
        else:
            requestObj = [iOS_Key]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "HideKeyboard was successful", "HideKeyboard failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class TouchAction_WaitCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.TouchAction_Wait")

    def execute(self, duration):
        requestObj = [duration]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "TouchAction_Wait was successful", "TouchAction_Wait failed")
